import type { Control, FieldValues, Path } from 'react-hook-form';

import { cn } from '~/lib/utils';

import {
  FormControl,
  FormDescription,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from '../ui/form';
import { Checkbox } from '../ui/checkbox';

type CheckboxFieldProps<TFieldValues extends FieldValues> = {
  control: Control<TFieldValues> | undefined;
  name: Path<TFieldValues>;
  label: string;
  options: { options: string[] };
  isPending: boolean;
};

const CheckboxField = <TFieldValues extends FieldValues>({
  control,
  name,
  label,
  options,
  isPending,
}: CheckboxFieldProps<TFieldValues>) => {
  return (
    <FormField
      control={control}
      name={name}
      render={({ field }) => (
        <div className='w-full'>
          <FormLabel className='text-2xl font-bold'>{label}</FormLabel>
          <div className='flex w-full flex-col items-center justify-center'>
            <FormItem className='w-full'>
              {options.options.map((item) => (
                <FormItem key={item} className='mx-auto w-full max-w-3xl'>
                  <FormControl>
                    <Checkbox
                      id={item}
                      disabled={isPending}
                      checked={(field.value as string[])?.includes(item) || false}
                      onCheckedChange={(checked) => {
                        const newValue = checked
                          ? [...((field.value as string[]) || []), item]
                          : (field.value as string[])?.filter((value) => value !== item);
                        field.onChange(newValue);
                      }}
                      className='hidden'
                    />
                  </FormControl>
                  <FormLabel
                    htmlFor={item}
                    className={cn(
                      'relative flex w-full cursor-pointer items-center justify-center rounded-lg border-2 px-6 py-4 text-center font-semibold transition-all duration-300',
                      isPending
                        ? 'cursor-not-allowed border-gray-400 bg-gray-200 text-gray-500' // Styles when disabled
                        : 'border-teal-600 hover:border-teal-700 hover:bg-teal-700 hover:text-white sm:h-[120px]',
                      (field.value as string[])?.includes(item) &&
                        !isPending &&
                        'border-teal-700 bg-teal-700 text-white shadow-lg'
                    )}
                  >
                    <div
                      className='text-lg leading-6 sm:text-xl'
                      style={{ fontWeight: 600, letterSpacing: 0.5 }}
                    >
                      <span>{item}</span>
                    </div>
                  </FormLabel>
                </FormItem>
              ))}
            </FormItem>
          </div>
          <FormDescription className='mt-2 text-start'>Scegline quanti ne vuoi</FormDescription>
          <FormMessage />
        </div>
      )}
    />
  );
};

export default CheckboxField;
